# LMMs Eval Documentation

Welcome to the docs for `lmms-eval`!

Majority of this documentation is adapted from [lm-eval-harness](https://github.com/EleutherAI/lm-evaluation-harness/)

## Table of Contents

* To learn about the command line flags, see the [commands](commands.md)
* To learn how to add a new moddel,  see the [Model Guide](model_guide.md).
* For a crash course on adding new tasks to the library, see our [Task Guide](task_guide.md).